==> xlniuxdata-jinzuan-1.0.4-20141021.062936-1-sources.jar: com/xunlei/niux/data/jinzuan/vo/Present.java <==
package com.xunlei.niux.data.jinzuan.vo;

import com.ferret.common.dao.annotation.Table;


/**
 * 赠送订单
 * @author lisu
 * 2014-05-07
 */
@Table(tableName="jinzuan_present",pkFieldName="seqId",pkFieldAssign=false)
public class Present {
	private Long seqId;
	private String ptype;
	private Long userId;
    private String orderid;
    private Boolean flag;
    private String startTime;
    private String endTime;
    private Long amount;
    private Integer timeType;
	private Long months;
    private String reason;
    private String presentOperater;
    private String presentTime;
    private String ext1;
  
    public String getPtype() {
		return ptype;
	}
	public void setPtype(String ptype) {
		this.ptype = ptype;
	}
    public Integer getTimeType() {
		return timeType;
	}
	public void setTimeType(Integer timeType) {
		this.timeType = timeType;
	}
	public Long getMonths() {
		return months;
	}
	public void setMonths(Long months) {
		this.months = months;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public Long getUserId() {
		return userId;
	}
	public void setUserId(Long userId) {
		this.userId = userId;
	}
	public String getOrderid() {
		return orderid;
	}
	public void setOrderid(String orderid) {
		this.orderid = orderid;
	}
	public Boolean getFlag() {
		return flag;
	}
	public void setFlag(Boolean flag) {
		this.flag = flag;
	}
	public String getStartTime() {
		return startTime;
	}
	public void setStartTime(String startTime) {
		this.startTime = startTime;
	}
	public String getEndTime() {
		return endTime;
	}
	public void setEndTime(String endTime) {
		this.endTime = endTime;
	}
	public Long getAmount() {
		return amount;
	}
	public void setAmount(Long amount) {
		this.amount = amount;
	}
	public String getReason() {
		return reason;
	}
	public void setReason(String reason) {
		this.reason = reason;
	}
	public String getPresentOperater() {
		return presentOperater;
	}
	public void setPresentOperater(String presentOperater) {
		this.presentOperater = presentOperater;
	}
	public String getPresentTime() {
		return presentTime;
	}
	public void setPresentTime(String presentTime) {
		this.presentTime = presentTime;
	}
	public String getExt1() {
		return ext1;
	}
	public void setExt1(String ext1) {
		this.ext1 = ext1;
	}

}

==> xlniuxdata-jinzuan-1.0.4-20150828.095541-9-sources.jar: com/xunlei/niux/data/jinzuan/vo/Present.java <==
package com.xunlei.niux.data.jinzuan.vo;

import com.ferret.common.dao.annotation.Table;


/**
 * 赠送订单
 * @author lisu
 * 2014-05-07
 */
@Table(tableName="jinzuan_present",pkFieldName="seqId",pkFieldAssign=false)
public class Present {
	private Long seqId;
	private String ptype;
	private Long userId;
    private String orderid;
    private Boolean flag;
    private String startTime;
    private String endTime;
    private Long amount;
    private Integer timeType;
	private Long months;
    private String reason;
    private String presentOperater;
    private String presentTime;
    private String ext1;
    private Integer memberType;
    
    
  
	public Integer getMemberType() {
		return memberType;
	}
	public void setMemberType(Integer memberType) {
		this.memberType = memberType;
	}
	public String getPtype() {
		return ptype;
	}
	public void setPtype(String ptype) {
		this.ptype = ptype;
	}
    public Integer getTimeType() {
		return timeType;
	}
	public void setTimeType(Integer timeType) {
		this.timeType = timeType;
	}
	public Long getMonths() {
		return months;
	}
	public void setMonths(Long months) {
		this.months = months;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public Long getUserId() {
		return userId;
	}
	public void setUserId(Long userId) {
		this.userId = userId;
	}
	public String getOrderid() {
		return orderid;
	}
	public void setOrderid(String orderid) {
		this.orderid = orderid;
	}
	public Boolean getFlag() {
		return flag;
	}
	public void setFlag(Boolean flag) {
		this.flag = flag;
	}
	public String getStartTime() {
		return startTime;
	}
	public void setStartTime(String startTime) {
		this.startTime = startTime;
	}
	public String getEndTime() {
		return endTime;
	}
	public void setEndTime(String endTime) {
		this.endTime = endTime;
	}
	public Long getAmount() {
		return amount;
	}
	public void setAmount(Long amount) {
		this.amount = amount;
	}
	public String getReason() {
		return reason;
	}
	public void setReason(String reason) {
		this.reason = reason;
	}
	public String getPresentOperater() {
		return presentOperater;
	}
	public void setPresentOperater(String presentOperater) {
		this.presentOperater = presentOperater;
	}
	public String getPresentTime() {
		return presentTime;
	}
	public void setPresentTime(String presentTime) {
		this.presentTime = presentTime;
	}
	public String getExt1() {
		return ext1;
	}
	public void setExt1(String ext1) {
		this.ext1 = ext1;
	}

}
